@@ -1,17 +1,35 @@
-( cd opt/kde/share/doc/HTML/cs/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kdm ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/konsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/konsole ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
+( cd opt/kde/share/doc/HTML/cs/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kgamma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmlowbatcrit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/passwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/email ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmstyle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmaccess ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 1.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 10.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/10.png 10.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 2.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/2.png 2.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 3.png )
@@ -28,123 +46,117 @@
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 9.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf artistic-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bottom1.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bottom2.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf bsd-license.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf docheadergears.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1a.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1b.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop2.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doxygen.css )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/fdl-license fdl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf footer.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/footer.html footer.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf gpl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/gpl-license gpl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf gpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf grad.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/grad.png grad.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf header.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf headerbg.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-common.css )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-default.css )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-localised.css.template )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-web.css )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kmenu.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf lgpl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf lgpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf mainfooter.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf mainheader.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf qpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf shadow.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/top-left.png top-left.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/cs/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/bell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/clock ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/email ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/passwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmaccess ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/crypto ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmstyle ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/laptop ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmsmserver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmlowbatcrit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf web-doctop.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf x11-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf xml.dcl )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
 ( cd opt/kde/share/doc/HTML/cs/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/kdeprint ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kgamma ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kgamma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/pci ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/scsi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/interrupts ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/devices ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/xserver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/sound ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/partitions ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/memory ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/pcmcia ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/processor ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/ioports ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/konsole ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kdm ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
